@@ -20,9 +20,11 @@ def b64encode(*args):
     'Simple wrapper so b64encode gives string output, for clarity.'
     return base64.b64encode(*args).decode('utf8')
 
-def b64decode(*args):
+def b64decode(foo, *args):
     'Only here for consistency with the above.'
-    return base64.b64decode(*args)
+    if isinstance(foo, str):
+        foo = foo.encode('utf8')
+    return base64.b64decode(foo, *args)
 
 def assert_type_and_length(varname, var, T, L = None, minL = None, maxL = None):
     'Facilitates simultaneous or one-line type/length checks.'
